User Guide: Inspecting an NWBFile
=================================

Neurodata Without Borders (NWB) provides a common self-describing format
ideal for archiving neurophysiology data and sharing it with colleagues.

A very important aspect of efficient data sharing and reuse is not only
to harness the standardized NWB data types, but also to follow
Best Practices when constructing metadata, organizing object locations
within a file, and using advanced I/O features such as compression.

This guide will make every attempt to walk you through the tools
available to aid you in adjusting your data conversion code in PyNWB or MatNWB
to adhere more strictly to the officially encouraged Best Practices.

.. toctree::
    :maxdepth: 2

    installation
    using_the_command_line_interface
    using_the_library
    using_the_library_advanced
